"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var constants_1 = require("../model/constants");
var unload_1 = require("../lifecycles/unload");
function isActive(app) {
    return app.status === constants_1.StatusEnum.MOUNTED;
}
function InActive(app) {
    return !isActive(app);
}
function shouldNotBeActive(app) {
    try {
        return !app.activeWhen(window.location);
    }
    catch (err) {
        app.status = constants_1.StatusEnum.SKIP_BECAUSE_BROKEN;
        throw new Error(err);
    }
}
function notSkipped(item) {
    return (item !== constants_1.StatusEnum.SKIP_BECAUSE_BROKEN &&
        (!item || item.status !== constants_1.StatusEnum.SKIP_BECAUSE_BROKEN));
}
function isLoaded(app) {
    return (app.status !== constants_1.StatusEnum.NOT_LOADED &&
        app.status !== constants_1.StatusEnum.LOADING_SOURCE_CODE);
}
function notLoaded(app) {
    return !isLoaded(app);
}
function shouldBeActive(app) {
    try {
        return app.activeWhen(window.location);
    }
    catch (err) {
        app.status = constants_1.StatusEnum.SKIP_BECAUSE_BROKEN;
        throw new Error(err);
    }
}
var StatusHelper = {
    getAppsToLoad: function (apps) {
        return apps
            .filter(notSkipped)
            .filter(notLoaded)
            .filter(shouldBeActive);
    },
    getAppsToUnload: function () {
        var appsToUnload = unload_1.getUnloadApps();
        return Object.keys(appsToUnload)
            .map(function (appName) { return appsToUnload[appName].app; })
            .filter(InActive);
    },
    getAppUnloadInfo: function (appName) {
        var appsToUnload = unload_1.getUnloadApps();
        return appsToUnload[appName];
    },
    getAppsToUnmount: function (apps) {
        return apps
            .filter(notSkipped)
            .filter(isActive)
            .filter(shouldNotBeActive);
    },
    getAppsToMount: function (apps) {
        return apps
            .filter(notSkipped)
            .filter(InActive)
            .filter(isLoaded)
            .filter(shouldBeActive);
    },
    getActiveApps: function (apps) {
        return apps.filter(notSkipped).filter(isActive);
    }
};
exports.default = StatusHelper;
//# sourceMappingURL=status.helper.js.map