"use strict";
// License (MIT)
// Copyright (c) 2013-2014 Christopher Simpkins
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var globalTimeoutConfig = {
    bootstrap: {
        millis: 4000,
        dieOnTimeout: false
    },
    mount: {
        millis: 3000,
        dieOnTimeout: false
    },
    unmount: {
        millis: 3000,
        dieOnTimeout: false
    },
    unload: {
        millis: 3000,
        dieOnTimeout: false
    }
};
function reasonableTime(promise, description, timeoutConfig, app) {
    var warningPeriod = 1000;
    return new Promise(function (resolve, reject) {
        var finished = false;
        var errored = false;
        promise
            .then(function (val) {
            finished = true;
            resolve(val);
        })
            .catch(function (val) {
            finished = true;
            reject(val);
        });
        setTimeout(function () { return maybeTimingOut(1); }, warningPeriod);
        setTimeout(function () { return maybeTimingOut(true); }, timeoutConfig.millis);
        function maybeTimingOut(shouldError) {
            if (!finished) {
                if (shouldError === true) {
                    errored = true;
                    if (timeoutConfig.dieOnTimeout) {
                        reject(description + " did not resolve or reject for " + timeoutConfig.millis + " milliseconds");
                    }
                    else {
                        // don't resolve or reject, we're waiting this one out
                        console.error(description + " did not resolve or reject for " + timeoutConfig.millis +
                            "milliseconds -- \n            we're no longer going to warn you about it.");
                    }
                }
                else if (!errored) {
                    var numWarnings_1 = shouldError;
                    var numMillis = numWarnings_1 * warningPeriod;
                    console.warn(description + " did not resolve or reject within " + numMillis + " milliseconds");
                    if (numMillis + warningPeriod < timeoutConfig.millis) {
                        setTimeout(function () { return maybeTimingOut(numWarnings_1 + 1); }, warningPeriod);
                    }
                }
            }
        }
    });
}
exports.reasonableTime = reasonableTime;
function ensureValidAppTimeouts(timeouts) {
    if (timeouts === void 0) { timeouts = {}; }
    return __assign({}, globalTimeoutConfig, timeouts);
}
exports.ensureValidAppTimeouts = ensureValidAppTimeouts;
//# sourceMappingURL=timeouts.js.map