"use strict";
/**
 * Robin Coma Delperier
 * Licensed under the Apache-2.0 License
 * https://github.com/PlaceMe-SAS/single-spa-angular-cli/blob/master/LICENSE
 *
 * modified by Phodal HUANG
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
var mooa_loader_helper_1 = require("../helper/mooa-loader.helper");
var dom_utils_1 = require("../helper/dom.utils");
function bootstrap(app) {
    if (!window['mooa']) {
        window.mooa = {};
    }
    window.mooa.isSingleSpa = true;
    window.mooa.name = app.name;
    if (app.mode && app.mode === 'iframe') {
        dom_utils_1.createApplicationIframeContainer(app);
        return new Promise(function (resolve, reject) {
            mooa_loader_helper_1.default.loadAllAssetsForIframe(app.appConfig).then(resolve, reject);
        });
    }
    else if (app.mode && app.mode === 'link') {
        dom_utils_1.createApplicationContainer(app);
        return new Promise(function (resolve, reject) {
            mooa_loader_helper_1.default.loadAllAssetsByUrl(app.appConfig).then(resolve, reject);
        });
    }
    else {
        dom_utils_1.createApplicationContainer(app);
        return new Promise(function (resolve, reject) {
            mooa_loader_helper_1.default.loadAllAssets(app.appConfig).then(resolve, reject);
        });
    }
}
function load(app) {
    return Promise.resolve();
}
function mount(app, props) {
    return new Promise(function (resolve, reject) {
        var aliasWindow = window;
        if (app.mode === 'iframe') {
            var iframe = document.getElementById(dom_utils_1.generateIFrameID(app.name));
            if (iframe && iframe.contentWindow) {
                aliasWindow = iframe.contentWindow;
            }
        }
        if (aliasWindow.mooa[app.name]) {
            aliasWindow.mooa[app.name].mount(props);
            resolve();
        }
        else {
            console.error("Cannot mount " + app.name + " because that is not bootstraped");
            reject();
        }
    });
}
function unmount(app, props) {
    var unloadApplication = props.unloadApplication, getAppNames = props.getAppNames;
    return new Promise(function (resolve, reject) {
        var aliasWindow = window;
        if (app.mode === 'iframe') {
            var iframe = document.getElementById(dom_utils_1.generateIFrameID(app.name));
            if (iframe && iframe.contentWindow) {
                aliasWindow = iframe.contentWindow;
            }
        }
        if (aliasWindow.mooa[app.name]) {
            aliasWindow.mooa[app.name].unmount();
            if (app.mode === 'iframe') {
                dom_utils_1.removeApplicationIframeContainer(app);
            }
            else {
                dom_utils_1.removeApplicationContainer(app);
            }
            if (getAppNames().indexOf(app.name) !== -1) {
                unloadApplication(app.name, { waitForUnmount: true });
                resolve();
            }
            else {
                reject("Cannot unmount " + app.name + " because that " + app.name + " is not part of the decalred applications : " + getAppNames());
            }
        }
        else {
            reject("Cannot unmount " + app.name + " because that is not bootstraped");
        }
    });
}
function unload(app) {
    return new Promise(function (resolve, reject) {
        app.appConfig.scripts
            .concat(app.appConfig.styles)
            .reduce(function (prev, scriptName) {
            return prev.then(mooa_loader_helper_1.default.unloadTag(app.appConfig, scriptName));
        }, Promise.resolve({}));
        resolve();
    });
}
function mooaLoader(opts) {
    return {
        bootstrap: bootstrap.bind(null, opts),
        load: load.bind(null, opts),
        mount: mount.bind(null, opts),
        unload: unload.bind(null, opts),
        unmount: unmount.bind(null, opts)
    };
}
exports.default = mooaLoader;
//# sourceMappingURL=mooa.loader.js.map