"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var app_helper_1 = require("../helper/app.helper");
window.mooa = window.mooa || {};
var MooaPlatform = /** @class */ (function () {
    function MooaPlatform() {
        this.name = '';
    }
    MooaPlatform.prototype.mount = function (name, router) {
        var _this = this;
        this.name = name;
        this.router = router;
        return new Promise(function (resolve, reject) {
            if (_this.isSingleSpaApp()) {
                app_helper_1.customEvent('mooa.child.mount', { name: _this.name });
                window.mooa[_this.name] = window.mooa[_this.name] || {};
                window.mooa[_this.name].mount = function (props) {
                    resolve({ props: props, attachUnmount: _this.unmount.bind(_this) });
                };
            }
            else {
                resolve({ props: {}, attachUnmount: _this.unmount.bind(_this) });
            }
        });
    };
    MooaPlatform.prototype.unmount = function (module) {
        var _this = this;
        if (this.isSingleSpaApp()) {
            app_helper_1.customEvent('mooa.child.unmount', { name: this.name });
            window.mooa[this.name].unmount = function () {
                if (module) {
                    module.destroy();
                    if (_this.router) {
                        module.injector.get(_this.router).dispose();
                    }
                }
            };
        }
    };
    MooaPlatform.prototype.appBase = function () {
        if (this.isSingleSpaApp()) {
            var pathNames = window.location.pathname.split('/');
            if (pathNames.length < 2) {
                return '/';
            }
            var parentRouter = pathNames[1];
            var appName = pathNames[2];
            var locationPath = '/' + parentRouter + '/' + appName;
            window.mooa.basePath = locationPath;
            return locationPath;
        }
        else {
            return '/';
        }
    };
    MooaPlatform.prototype.navigateTo = function (opts) {
        app_helper_1.customEvent('mooa.routing.navigate', opts);
    };
    MooaPlatform.prototype.handleRouterUpdate = function (router, appName) {
        window.addEventListener('mooa.routing.change', function (event) {
            if (event.detail.app.name === appName) {
                var urlPrefix = 'app';
                if (urlPrefix) {
                    urlPrefix = "/" + window.mooa.option.urlPrefix + "/";
                }
                router.navigate([event.detail.url.replace(urlPrefix + appName, '')]);
            }
        });
    };
    MooaPlatform.prototype.isSingleSpaApp = function () {
        return window.mooa.isSingleSpa;
    };
    return MooaPlatform;
}());
exports.MooaPlatform = MooaPlatform;
exports.default = MooaPlatform;
//# sourceMappingURL=platform.js.map